<?php

namespace TMWS\Tikilive;

class Oembed {

    private static $_instance;

    public function __construct() {
        add_action( 'init', [$this, 'init'] );
        add_action( 'template_redirect', [$this, 'template_redirect'] );

        add_action( 'after_setup_theme', [$this, 'after_setup_theme'] );

        add_filter( 'oembed_providers', [$this, 'oembed_providers'] );
        add_filter( 'oembed_result', [$this, 'oembed_result'], 10, 3 );
        add_filter( 'oembed_fetch_url', [$this, 'oembed_fetch_url'], 10, 3 );
    }
    
    public function init() {
        add_rewrite_endpoint( 'tikilive-oembed', EP_ALL );
    }
    
    public function after_setup_theme() {
    }

    public function template_redirect( $template ) {
        global $wp_query;
 
        if ( ! isset( $wp_query->query_vars['tikilive-oembed'] ) ){
            return;
        }

        $filter_demention = [
            'filter' => FILTER_VALIDATE_INT,
            'options' => [
                'default' => 1000
            ]
        ];

        $filter_format = [
            'filter' => FILTER_VALIDATE_REGEXP,
            'options' => [
                'regexp' => '/(json|xml)/i',
                'default' => 'json'
            ]
        ];

        $input = \filter_input_array( INPUT_GET, [
            'maxwidth' => $filter_demention,
            'maxheight' => $filter_demention,
            'url' => FILTER_VALIDATE_URL,
            'dnt' => FILTER_VALIDATE_BOOLEAN,
            'format' => $filter_format,
        ] );

        if( !$input || empty( $input['url'] ) ) {
            $this->_not_implemented();
        }

        $result = wp_remote_get( $input['url'] );

        //error_log(print_r($result, true));

        if( !is_array( $result ) || \is_wp_error( $result ) ) {
            $this->_not_implemented();
        }

        $response_data = [
            'version' => '1.0',
            'type' => 'video',
        ];

        $dom = new \DOMDocument();

        \libxml_use_internal_errors( true );

        $dom->loadHTML( $result['body'] );

        $data = new \DOMXPath( $dom );
        
        $titleNodes = $data->query( "//head/title" );
        if( $titleNodes && $titleNodes->length ) {
           $response_data['title'] = $titleNodes->item(0)->nodeValue; 
        }

        $authorNameNodes = $data->query( "//head/meta[@name='twitter:site']" );
        if( $authorNameNodes && $authorNameNodes->length ) {
           $response_data['author_name'] = $authorNameNodes->item(0)->attributes->getNamedItem('content')->textContent; 
        }

        $authorUrlNodes = $data->query( "//head/meta[@name='twitter:url']" );
        if( $authorUrlNodes && $authorUrlNodes->length ) {
           $response_data['author_url'] = $authorUrlNodes->item(0)->attributes->getNamedItem('content')->textContent; 
        }

        $htmlNodes = $data->query( "//input[@id='embed_code_id']" );
        if( $htmlNodes && $htmlNodes->length ) {
           $response_data['html'] = $htmlNodes->item(0)->attributes->getNamedItem('value')->textContent;
           $response_data['width'] = $input['maxwidth'];
           $response_data['height'] = $input['maxheight'];
        }

        $thumbnailNode = $data->query( "//head/meta[@name='twitter:image']" );
        if( $thumbnailNode && $thumbnailNode->length ) {

            $thumbnail_url = $thumbnailNode->item(0)->attributes->getNamedItem('content')->textContent;
            $size = sprintf( '-%dx%d-', $input['maxwidth'], $input['maxheight'] );

            $response_data['thumbnail_url'] = \preg_replace( '`-\d+x\d+-`', $size, $thumbnail_url );
            $response_data['thumbnail_width'] = $input['maxwidth'];
            $response_data['thumbnail_heigh'] = $input['maxheight'];
        }

        header( 'Content-Type: application/json' );
        echo wp_json_encode( $response_data );
        exit;
    }

    private function _not_implemented() {
        header( $SERVER['SERVER_PROTOCOL'] . ' 501 Not Implemented' );
        exit;
    }

    
    public function oembed_providers( $providers=array() ) {
        $providers['#https?://((m|www)\.)?tikilive\.com/video/.*#i'] = array( get_site_url( null, '/tikilive-oembed' ), true );
        return $providers;
    }

    public function oembed_fetch_url ( $provider, $url, $args ) {
        //error_log(print_r(['provider' => $provider, 'url' => $url, 'args' => $args], true));
        return $provider;
    }

    public function oembed_result( $html, $data, $args ) {
        //error_log(print_r(['html' => $html, 'data' => $data, 'args' => $args], true));
        return $html;
    }

    public static function instance() {

        if(null == self::$_instance) {
            self::$_instance = new self;
        }

        return self::$_instance;
    }
}

Oembed::instance();
